==> totoui-0.3.0.tgz: package/lib/dateTimePicker.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _fecha = require('fecha');

var _fecha2 = _interopRequireDefault(_fecha);

var _datePickerJsx = require('./datePicker.js');

var _datePickerJsx2 = _interopRequireDefault(_datePickerJsx);

var _timePickerJsx = require('./timePicker.js');

var _timePickerJsx2 = _interopRequireDefault(_timePickerJsx);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var DateTimePicker = (function (_React$Component) {
    _inherits(DateTimePicker, _React$Component);

    function DateTimePicker(props) {
        _classCallCheck(this, DateTimePicker);

        _get(Object.getPrototypeOf(DateTimePicker.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }

        var showToggle = undefined;
        var showTimePicker = undefined;

        if (this.props.showTimePicker && this.props.showDatePicker) {
            showToggle = true;
            showTimePicker = false;
        }

        if (!showToggle && !this.props.showDatePicker) {
            showTimePicker = true;
        }

        this.state = {
            showTimePicker: showTimePicker,
            showDatePicker: this.props.showDatePicker,
            caretDisplayed: this.props.caretDisplayed,
            showToggle: showToggle,
            date: _fecha2['default'].parse(this.props.dateTime, this.props.format),
            toggleDisplay: {
                toggleTime: { display: 'block' },
                toggleDate: { display: 'none' }
            }
        };

        this.handleToggleTime = this.handleToggleTime.bind(this);
        this.handleToggleDate = this.handleToggleDate.bind(this);
        this.handleSelect = this.handleSelect.bind(this);
        this.renderToggleTime = this.renderToggleTime.bind(this);
        this.renderToggleDate = this.renderToggleDate.bind(this);
        this.renderDatePicker = this.renderDatePicker.bind(this);
        this.renderTimePicker = this.renderTimePicker.bind(this);
        this.renderCaret = this.renderCaret.bind(this);
    }

    _createClass(DateTimePicker, [{
        key: 'handleToggleTime',
        value: function handleToggleTime() {
            this.setState({
                showDatePicker: false,
                showTimePicker: true,
                toggleDisplay: {
                    toggleTime: { display: 'none' },
                    toggleDate: { display: 'block' }
                }
            });
        }
    }, {
        key: 'handleToggleDate',
        value: function handleToggleDate() {
            this.setState({
                showDatePicker: true,
                showTimePicker: false,
                toggleDisplay: {
                    toggleTime: { display: 'block' },
                    toggleDate: { display: 'none' }
                }
            });
        }
    }, {
        key: 'handleSelect',
        value: function handleSelect(date) {
            this.setState({
                date: date
            });
            this.props.onSelect(_fecha2['default'].format(date, this.props.format));
        }
    }, {
        key: 'renderToggleTime',
        value: function renderToggleTime() {
            if (this.state.showToggle) {
                return _react2['default'].createElement(
                    'div',
                    { style: this.state.toggleDisplay.toggleTime, className: this.prefixClass('toggle'), onClick: this.handleToggleTime },
                    _react2['default'].createElement(_iconJsx2['default'], { icon: "clock-o" })
                );
            }
        }
    }, {
        key: 'renderToggleDate',
        value: function renderToggleDate() {
            if (this.state.showToggle) {
                return _react2['default'].createElement(
                    'div',
                    { style: this.state.toggleDisplay.toggleDate, className: this.prefixClass('toggle'), onClick: this.handleToggleDate },
                    _react2['default'].createElement(_iconJsx2['default'], { icon: "calendar" })
                );
            }
        }
    }, {
        key: 'renderDatePicker',
        value: function renderDatePicker() {
            if (this.state.showDatePicker) {
                return _react2['default'].createElement(_datePickerJsx2['default'], {
                    onSelect: this.handleSelect,
                    onClose: this.props.onClose,
                    weekStart: this.props.weekStart,
                    viewMode: this.props.viewMode,
                    minViewMode: this.props.minViewMode,
                    daysOfWeekDisabled: this.props.daysOfWeekDisabled,
                    format: this.props.format,
                    date: this.state.date,
                    locale: this.props.locale,
                    minDate: this.props.minDate,
                    maxDate: this.props.maxDate });
            }
        }
    }, {
        key: 'renderTimePicker',
        value: function renderTimePicker() {
            if (this.state.showTimePicker) {
                return _react2['default'].createElement(_timePickerJsx2['default'], {
                    onSelect: this.handleSelect,
                    date: this.state.date,
                    format: this.props.format });
            }
        }
    }, {
        key: 'renderCaret',
        value: function renderCaret() {
            if (this.state.caretDisplayed) {
                return _react2['default'].createElement('div', { className: this.prefixClass('caret') });
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            this.props.amStyle && (classSet[this.prefixClass(this.props.amStyle)] = true);

            return _react2['default'].createElement(
                'div',
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    style: this.props.style }),
                this.renderCaret(),
                _react2['default'].createElement(
                    'div',
                    { className: this.prefixClass('date') },
                    this.renderDatePicker()
                ),
                _react2['default'].createElement(
                    'div',
                    { className: this.prefixClass('time') },
                    this.renderTimePicker()
                ),
                this.renderToggleTime(),
                this.renderToggleDate()
            );
        }
    }]);

    return DateTimePicker;
})(_react2['default'].Component);

DateTimePicker.displayName = "Icon";

DateTimePicker.propTypes = {
    showTimePicker: _react2['default'].PropTypes.bool,
    showDatePicker: _react2['default'].PropTypes.bool,
    caretDisplayed: _react2['default'].PropTypes.bool,
    amStyle: _react2['default'].PropTypes.oneOfType(['success', 'danger', 'warning']),
    viewMode: _react2['default'].PropTypes.string,
    minViewMode: _react2['default'].PropTypes.string,
    onSelect: _react2['default'].PropTypes.func.isRequired,
    onClose: _react2['default'].PropTypes.func,
    daysOfWeekDisabled: _react2['default'].PropTypes.array,
    format: _react2['default'].PropTypes.string,
    dateTime: _react2['default'].PropTypes.string,
    locale: _react2['default'].PropTypes.string,
    weekStart: _react2['default'].PropTypes.number,
    minDate: _react2['default'].PropTypes.string,
    maxDate: _react2['default'].PropTypes.string
};

DateTimePicker.defaultProps = {
    classPrefix: 'datepicker',
    dateTime: '',
    format: 'YYYY-MM-DD HH:mm',
    showTimePicker: true,
    showDatePicker: true,
    caretDisplayed: true
};

module.exports = DateTimePicker;

==> totoui-0.5.1.tgz: package/lib/dateTimePicker.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _fecha = require('fecha');

var _fecha2 = _interopRequireDefault(_fecha);

var _datePickerJsx = require('./datePicker.js');

var _datePickerJsx2 = _interopRequireDefault(_datePickerJsx);

var _timePickerJsx = require('./timePicker.js');

var _timePickerJsx2 = _interopRequireDefault(_timePickerJsx);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var DateTimePicker = (function (_React$Component) {
    _inherits(DateTimePicker, _React$Component);

    function DateTimePicker(props) {
        _classCallCheck(this, DateTimePicker);

        _get(Object.getPrototypeOf(DateTimePicker.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }

        var showToggle = undefined;
        var showTimePicker = undefined;

        if (this.props.showTimePicker && this.props.showDatePicker) {
            showToggle = true;
            showTimePicker = false;
        }

        if (!showToggle && !this.props.showDatePicker) {
            showTimePicker = true;
        }

        this.state = {
            showTimePicker: showTimePicker,
            showDatePicker: this.props.showDatePicker,
            caretDisplayed: this.props.caretDisplayed,
            showToggle: showToggle,
            date: _fecha2['default'].parse(this.props.dateTime, this.props.format),
            toggleDisplay: {
                toggleTime: { display: 'block' },
                toggleDate: { display: 'none' }
            }
        };

        this.handleToggleTime = this.handleToggleTime.bind(this);
        this.handleToggleDate = this.handleToggleDate.bind(this);
        this.handleSelect = this.handleSelect.bind(this);
        this.renderToggleTime = this.renderToggleTime.bind(this);
        this.renderToggleDate = this.renderToggleDate.bind(this);
        this.renderDatePicker = this.renderDatePicker.bind(this);
        this.renderTimePicker = this.renderTimePicker.bind(this);
        this.renderCaret = this.renderCaret.bind(this);
    }

    _createClass(DateTimePicker, [{
        key: 'handleToggleTime',
        value: function handleToggleTime() {
            this.setState({
                showDatePicker: false,
                showTimePicker: true,
                toggleDisplay: {
                    toggleTime: { display: 'none' },
                    toggleDate: { display: 'block' }
                }
            });
        }
    }, {
        key: 'handleToggleDate',
        value: function handleToggleDate() {
            this.setState({
                showDatePicker: true,
                showTimePicker: false,
                toggleDisplay: {
                    toggleTime: { display: 'block' },
                    toggleDate: { display: 'none' }
                }
            });
        }
    }, {
        key: 'handleSelect',
        value: function handleSelect(date) {
            this.setState({
                date: date
            });
            this.props.onSelect(_fecha2['default'].format(date, this.props.format));
        }
    }, {
        key: 'renderToggleTime',
        value: function renderToggleTime() {
            if (this.state.showToggle) {
                return _react2['default'].createElement(
                    'div',
                    { style: this.state.toggleDisplay.toggleTime, className: this.prefixClass('toggle'), onClick: this.handleToggleTime },
                    _react2['default'].createElement(_iconJsx2['default'], { icon: 'clock-o' })
                );
            }
        }
    }, {
        key: 'renderToggleDate',
        value: function renderToggleDate() {
            if (this.state.showToggle) {
                return _react2['default'].createElement(
                    'div',
                    { style: this.state.toggleDisplay.toggleDate, className: this.prefixClass('toggle'), onClick: this.handleToggleDate },
                    _react2['default'].createElement(_iconJsx2['default'], { icon: 'calendar' })
                );
            }
        }
    }, {
        key: 'renderDatePicker',
        value: function renderDatePicker() {
            if (this.state.showDatePicker) {
                return _react2['default'].createElement(_datePickerJsx2['default'], {
                    onSelect: this.handleSelect,
                    onClose: this.props.onClose,
                    weekStart: this.props.weekStart,
                    viewMode: this.props.viewMode,
                    minViewMode: this.props.minViewMode,
                    daysOfWeekDisabled: this.props.daysOfWeekDisabled,
                    format: this.props.format,
                    date: this.state.date,
                    locale: this.props.locale,
                    minDate: this.props.minDate,
                    maxDate: this.props.maxDate });
            }
        }
    }, {
        key: 'renderTimePicker',
        value: function renderTimePicker() {
            if (this.state.showTimePicker) {
                return _react2['default'].createElement(_timePickerJsx2['default'], {
                    onSelect: this.handleSelect,
                    date: this.state.date,
                    format: this.props.format });
            }
        }
    }, {
        key: 'renderCaret',
        value: function renderCaret() {
            if (this.state.caretDisplayed) {
                return _react2['default'].createElement('div', { className: this.prefixClass('caret') });
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            this.props.amStyle && (classSet[this.prefixClass(this.props.amStyle)] = true);

            return _react2['default'].createElement(
                'div',
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    style: this.props.style }),
                this.renderCaret(),
                _react2['default'].createElement(
                    'div',
                    { className: this.prefixClass('date') },
                    this.renderDatePicker()
                ),
                _react2['default'].createElement(
                    'div',
                    { className: this.prefixClass('time') },
                    this.renderTimePicker()
                ),
                this.renderToggleTime(),
                this.renderToggleDate()
            );
        }
    }]);

    return DateTimePicker;
})(_react2['default'].Component);

DateTimePicker.displayName = "Icon";

DateTimePicker.propTypes = {
    showTimePicker: _react2['default'].PropTypes.bool,
    showDatePicker: _react2['default'].PropTypes.bool,
    caretDisplayed: _react2['default'].PropTypes.bool,
    amStyle: _react2['default'].PropTypes.oneOfType(['success', 'danger', 'warning']),
    viewMode: _react2['default'].PropTypes.string,
    minViewMode: _react2['default'].PropTypes.string,
    onSelect: _react2['default'].PropTypes.func.isRequired,
    onClose: _react2['default'].PropTypes.func,
    daysOfWeekDisabled: _react2['default'].PropTypes.array,
    format: _react2['default'].PropTypes.string,
    dateTime: _react2['default'].PropTypes.string,
    locale: _react2['default'].PropTypes.string,
    weekStart: _react2['default'].PropTypes.number,
    minDate: _react2['default'].PropTypes.string,
    maxDate: _react2['default'].PropTypes.string
};

DateTimePicker.defaultProps = {
    classPrefix: 'datepicker',
    dateTime: '',
    format: 'YYYY-MM-DD HH:mm',
    showTimePicker: true,
    showDatePicker: true,
    caretDisplayed: true
};

module.exports = DateTimePicker;
